@@ -38,21 +38,8 @@ def render(rq, to, context=None, **response_kwargs):
 
 @cached_function
 def _json_dumps():
-    try:
-        import simplejson as json
-    except ImportError:
-        import json
-    except ImportError:
-        from django.utils import simplejson as json
-    except ImportError:
-        raise ImportError('Json module not found')
-    kw = {'default': json_default_handler}
-    if cfg.DEBUG:
-        kw['indent'] = 2
-    return lambda obj: json.dumps(obj, **kw)
-
-def json_default_handler(obj):
-    return obj.isoformat() if isinstance(obj, datetime) else None
+    import asjson
+    return lambda obj: asjson.dumps(obj, debug=cfg.DEBUG)
 
 
 @cached_function
